@@ -130,13 +130,21 @@ class JyInterface(object):
         return int(response.message)
 
     def getPosition(self, symbol: str):
-        symstr = symbol.split('/', 1)
-        response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
-                                                                   appKey=self.appKey,
-                                                                   secret=self.secret,
-                                                                   passphrase=self.passphrase,
-                                                                   futureOrSpot=self.futureOrSpot,
-                                                                   mark=symstr[0]))
+        if self.futureOrSpot == 0:
+            symstr = symbol.split('/', 1)
+            response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
+                                                                       appKey=self.appKey,
+                                                                       secret=self.secret,
+                                                                       passphrase=self.passphrase,
+                                                                       futureOrSpot=self.futureOrSpot,
+                                                                       mark=symstr[0]))
+        else:
+            response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
+                                                                       appKey=self.appKey,
+                                                                       secret=self.secret,
+                                                                       passphrase=self.passphrase,
+                                                                       futureOrSpot=self.futureOrSpot,
+                                                                       mark=symbol))            
         return float(response.message)
 
     def getMargin(self, symbol: str):
